import 'dart:convert';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:loyalty_management_tool/utils/text_styling.dart';

import '../../models/bank_details_response.dart';
import '../../models/base_res.dart';
import '../../models/location_reponse_data.dart';
import '../../notifications/address_notification.dart';
import '../../utils/basicInfo.dart';
import '../../utils/empty_widget.dart';
import '../../utils/localization.dart';
import '../cubits/cubit_main.dart';
import '../states/main_state.dart';
import '../states/states.dart';
import 'loading_indicator.dart';

class AccountDetailsBillingWidget extends StatefulWidget {
  final String? avatar;
  final String? title;
  final String? subTitle;

  AccountDetailsBillingWidget({Key? key, this.avatar, this.title, this.subTitle}) : super(key: key);

  @override
  AccountDetailsBillingWidgetState createState() =>
      AccountDetailsBillingWidgetState();
}

class AccountDetailsBillingWidgetState
    extends State<AccountDetailsBillingWidget> {
  BasicInfo? basicInfo = BasicInfo();

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance!.addPostFrameCallback((_) {
      dataFetch();
    });
  }

  Future<void> dataFetch()
  async {
    await  BlocProvider.of<CubitMain>(context).getData(getBody(), context, basicInfo!.location, getData);

    await BlocProvider.of<CubitMain>(context).getGstNumber(getGSTBody(), context,  basicInfo!.userProfile, getProfileData);

    BlocProvider.of<CubitMain>(context).getAccountDetal(bankDetailsBody(), context,  basicInfo!.bankDetail, getBankData);

  }



  String getBody() {
    return jsonEncode({
      "business_id": basicInfo!.businessId,
    });
  }
  String getGSTBody() {
    return jsonEncode({
      "business_id": basicInfo!.businessId,
      "person_id": basicInfo!.userId,
      "detail_type": "business",
      "owner_id": basicInfo!.userId
    });
  }

  String bankDetailsBody()
  {return  jsonEncode({
    "owner_type": "business",
    "owner_id": basicInfo!.businessId
  });}


  dynamic getData(dynamic data) {
    return LocationDetailsResponse.fromJson(data);
  }
  dynamic getProfileData(dynamic data) {
    return BaseResponses.fromJson(data);
  }


  dynamic getBankData(dynamic data) {
    return BankAccountDetailsResponse.fromJson(data);
  }
  TextStyleElements? styleElements;



  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);

    return BlocBuilder<CubitMain, MainState>(builder: (context, state) {
        if (state is LoadingState) {
          return LoadingIndicator();
        } else if (state is LoadedWithData) {

          return   Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Expanded(
                child: Padding(
                  padding:
                  const EdgeInsets.only(top: 8.0, bottom: 8.0, left: 8, right: 8),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: <Widget>[
                      Align(
                          alignment: Alignment.topLeft,
                          child: Container(
                            margin: const EdgeInsets.only(top: 20),
                            child: Text(
                              "Account Number",
                              maxLines: 1,
                              style: styleElements!.subtitle2ThemeScalable(context),
                              textAlign: TextAlign.left,
                            ),
                          )),
                      Align(
                          alignment: Alignment.topLeft,
                          child: Container(
                            margin: const EdgeInsets.only(
                              top: 8,
                            ),
                            child: Text(
                              state.bankData??"--",
                              style: styleElements!
                                  .bodyText1ThemeScalable(context)
                                  .copyWith(fontWeight: FontWeight.w600),
                              textAlign: TextAlign.left,
                            ),
                          )),
                      Align(
                          alignment: Alignment.topLeft,
                          child: Container(
                            margin: const EdgeInsets.only(top: 20),
                            child: Text(
                              "GSTN",
                              maxLines: 1,
                              style: styleElements!.subtitle2ThemeScalable(context),
                              textAlign: TextAlign.left,
                            ),
                          )),
                      Align(
                          alignment: Alignment.topLeft,
                          child: Container(
                            margin: const EdgeInsets.only(right: 16),
                            child: Text(
                              state.gst??"--",
                              style: styleElements!
                                  .bodyText1ThemeScalable(context)
                                  .copyWith(fontWeight: FontWeight.w600),
                              textAlign: TextAlign.left,
                            ),
                          )),
                    ],
                  ),
                ),
              ),
              Expanded(
                child: Align(
                  alignment: Alignment.centerRight,
                  child: Padding(
                    padding: const EdgeInsets.only(
                        top: 8.0, bottom: 8.0, right: 8.0, left: 20),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: <Widget>[
                        Align(
                            alignment: Alignment.topLeft,
                            child: Container(
                              margin: const EdgeInsets.only(top: 20),
                              child: Text(
                                "Billing address",
                                maxLines: 1,
                                style: styleElements!.subtitle2ThemeScalable(context),
                                textAlign: TextAlign.left,
                              ),
                            )),
                        Align(
                            alignment: Alignment.topLeft,
                            child: Container(
                              margin: const EdgeInsets.only(
                                top: 8,
                              ),
                              child: Text(
                                state.data[0].streetAddress??"",
                                style: styleElements!
                                    .bodyText2ThemeScalable(context)
                                    .copyWith(fontWeight: FontWeight.w600),
                                textAlign: TextAlign.left,
                              ),
                            )),
                        Align(
                            alignment: Alignment.topLeft,
                            child: Container(
                              margin: const EdgeInsets.only(
                                top: 8,
                              ),
                              child: Text(
                                state.data[0].postalCode??"",
                                style: styleElements!.bodyText2ThemeScalable(context),
                                textAlign: TextAlign.left,
                              ),
                            )),

                      ],
                    ),
                  ),
                ),
              ),
            ],
          );
        } else {
          return Container(
            child: Center(
              child: EmptyWidget(
                  message:
                  AppLocalizationsRewards.of(context)!.translate("no_data")),
            ),
          );
        }
      });





  }
}
