import 'package:flutter/material.dart';
import 'package:intl/intl.dart';

import 'package:loyalty_management_tool/utils/colors.dart';
import 'package:loyalty_management_tool/utils/hexColors.dart';
import 'package:loyalty_management_tool/utils/localization.dart';
import 'package:loyalty_management_tool/utils/text_styling.dart';

import '../../models/cash_coin_resppnse.dart';

class InvoiceCard extends StatefulWidget {
  final String? avatar;
  final String? title;
  final String? subTitle;
  final  Rows data;

  InvoiceCard({this.avatar, this.title, this.subTitle,required this.data});

  @override
  InvoiceCardState createState() => InvoiceCardState();
}


class InvoiceCardState extends State<InvoiceCard> {
  final DateFormat formatter = DateFormat('dd-MM-yyyy');
  TextStyleElements? styleElements;
  late String formatted;

  @override
  void initState() {
    var dateTime=DateTime.now();
   formatted = formatter.format(dateTime);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return Column(
      crossAxisAlignment: CrossAxisAlignment.center,
      mainAxisSize: MainAxisSize.min,
      children: [
        Padding(
          padding: const EdgeInsets.only(top: 8.0, bottom: 8.0),
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Text(
                "Order date",
                maxLines: 2,
                overflow: TextOverflow.ellipsis,
                style: styleElements!.subtitle2ThemeScalable(context),
              ),
              Text(formatted,
                  maxLines: 2,
                  overflow: TextOverflow.ellipsis,
                  style: styleElements!.headline6ThemeScalableW(context)),
            ],
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(top: 8.0, bottom: 4.0),
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Text(
                widget.subTitle ?? "-",
                maxLines: 2,
                overflow: TextOverflow.ellipsis,
                style: styleElements!.subtitle1ThemeScalable(context),
              ),
            ],
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(top: 8.0, bottom: 8.0),
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Text(
                'Qty: '+widget.data.cashOrCoins.toString(),
                maxLines: 2,
                overflow: TextOverflow.ellipsis,
                style: styleElements!.subtitle2ThemeScalable(context),
              ),
              Text( AppLocalizationsRewards.of(context)!.translate("rupee_symbol")+    widget.data.payableAmount.toString(),
                  maxLines: 2,
                  overflow: TextOverflow.ellipsis,
                  style: styleElements!.headline6ThemeScalableW(context)),
            ],
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(top: 8.0, bottom: 8.0),
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Text(
                "Sub Total",
                maxLines: 2,
                overflow: TextOverflow.ellipsis,
                style: styleElements!.subtitle2ThemeScalable(context),
              ),
              Text( AppLocalizationsRewards.of(context)!.translate("rupee_symbol")+    widget.data.payableAmount.toString(),
                  maxLines: 2,
                  overflow: TextOverflow.ellipsis,
                  style: styleElements!.headline6ThemeScalableW(context)),
            ],
          ),
        ),
        const Divider(
          height: 2,
          thickness: 0.5,
          indent: 0,
          endIndent: 0,
        ),
        Padding(
          padding: const EdgeInsets.only(top: 8.0, bottom: 8.0),
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Text(
                "Tax",
                maxLines: 2,
                overflow: TextOverflow.ellipsis,
                style: styleElements!.subtitle1ThemeScalable(context),
              ),
            ],
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(top: 8.0, bottom: 8.0),
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Text(
                "IGST",
                maxLines: 2,
                overflow: TextOverflow.ellipsis,
                style: styleElements!.subtitle2ThemeScalable(context),
              ),
              Text( AppLocalizationsRewards.of(context)!.translate("rupee_symbol")+   widget.data.taxDetails!.igst.toString(),
                  maxLines: 2,
                  overflow: TextOverflow.ellipsis,
                  style: styleElements!.headline6ThemeScalableW(context)),
            ],
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(top: 8.0, bottom: 8.0),
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Text(
                "SGST",
                maxLines: 2,
                overflow: TextOverflow.ellipsis,
                style: styleElements!.subtitle2ThemeScalable(context),
              ),
              Text( AppLocalizationsRewards.of(context)!.translate("rupee_symbol")+    widget.data.taxDetails!.sgst.toString(),
                  maxLines: 2,
                  overflow: TextOverflow.ellipsis,
                  style: styleElements!.headline6ThemeScalableW(context)),
            ],
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(top: 8.0, bottom: 8.0),
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Text(
                "CGST",
                maxLines: 2,
                overflow: TextOverflow.ellipsis,
                style: styleElements!.subtitle2ThemeScalable(context),
              ),
              Text(AppLocalizationsRewards.of(context)!.translate("rupee_symbol")+   widget.data.taxDetails!.gst.toString(),
                  maxLines: 2,
                  overflow: TextOverflow.ellipsis,
                  style: styleElements!.headline6ThemeScalableW(context)),
            ],
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(top: 8.0, bottom: 8.0),
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Text(
                "Total Tax",
                maxLines: 2,
                overflow: TextOverflow.ellipsis,
                style: styleElements!.subtitle2ThemeScalable(context),
              ),
              Text(AppLocalizationsRewards.of(context)!.translate("rupee_symbol")+  widget.data.taxAmount!.toString(),
                  maxLines: 2,
                  overflow: TextOverflow.ellipsis,
                  style: styleElements!.headline6ThemeScalableW(context)),
            ],
          ),
        ),
        const Divider(
          height: 2,
          thickness: 0.5,
          indent: 0,
          endIndent: 0,
        ),
        Padding(
          padding: const EdgeInsets.only(top: 8.0, bottom: 8.0),
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Text(
                "Grand total",
                maxLines: 2,
                overflow: TextOverflow.ellipsis,
                style: styleElements!.subtitle2ThemeScalable(context),
              ),
              Text(AppLocalizationsRewards.of(context)!.translate("rupee_symbol")+  widget.data.payableAmount!.toString(),
                  maxLines: 2,
                  overflow: TextOverflow.ellipsis,
                  style: styleElements!.headline6ThemeScalableW(context)),
            ],
          ),
        ),
        const Divider(
          height: 2,
          thickness: 0.5,
          indent: 0,
          endIndent: 0,
        ),
      ],
    );
  }
}
