import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:loyalty_management_tool/models/rewards_list_response.dart';
import 'package:loyalty_management_tool/utils/colors.dart';
import 'package:loyalty_management_tool/utils/hexColors.dart';
import 'package:loyalty_management_tool/utils/localization.dart';
import 'package:loyalty_management_tool/utils/text_styling.dart';

import '../../models/cash_coin_resppnse.dart';
import '../../models/enums/payments_enums.dart';
import '../../utils/app_buttons.dart';
import '../../utils/basicInfo.dart';
import '../cubits/cubit_main.dart';
import '../states/main_state.dart';
import '../states/states.dart';

class RechargeWalletCoins extends StatefulWidget {
  final String title;
  final bool isBothValueRequired;
  final String subTitle;
  final String firstItemHint;
  final String firstItemTag;

  final Widget firstItemIcon;

  final RewardsItem? item;

  final num? giftCash;
  final num? giftCoin;
  final num? redemptionPercentage;
  final num? redemptionCoins;
  final String type;
  final Function(dynamic data) nextCallBack;
  final Function refreshCallBack;
  const RechargeWalletCoins({
    Key? key,
    this.giftCash,
    required this.refreshCallBack,
    required this.type,
    this.giftCoin,
    this.redemptionPercentage,
    this.redemptionCoins,
    required this.title,
    this.isBothValueRequired = false,
    required this.subTitle,
    this.item,
    required this.nextCallBack,
    required this.firstItemIcon,
    required this.firstItemHint,
    required this.firstItemTag,
  }) : super(key: key);

  @override
  RechargeWalletCoinsState createState() => RechargeWalletCoinsState();
}

class RechargeWalletCoinsState extends State<RechargeWalletCoins> {
  GlobalKey<FormState> formKey = GlobalKey();

  final cashController = TextEditingController();
  BasicInfo? basicInfo = BasicInfo();
  late TextStyleElements styleElements;
  late Widget cash;

  @override
  initState() {

    WidgetsBinding.instance!.addPostFrameCallback((_) {
      cashController.text="100";
      BlocProvider.of<CubitMain>(context).getCashCoinRechargeInfo(
          getBody(100),
          context,
          basicInfo!.fetchCashCoinData,
          getData,
          100);
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    BasicInfo? basicInfo = BasicInfo();
    cash = TextFormField(
      controller: cashController,
      cursorColor: HexColor(AppColors.appMainColor),
      onChanged: (enetredAmount) {
        BlocProvider.of<CubitMain>(context).getCashCoinRechargeInfo(
            getBody(num.parse(enetredAmount)),
            context,
            basicInfo.fetchCashCoinData,
            getData,
            num.parse(enetredAmount));
      },
      keyboardType: TextInputType.number,
      style: styleElements
          .subtitle1ThemeScalable(context)
          .copyWith(color: HexColor(AppColors.appColorBlack65)),
      decoration: InputDecoration(
        fillColor: Colors.black12,
        filled: true,

        prefixIcon: widget.firstItemIcon,
        hintText: widget.firstItemHint,
        hintStyle:  styleElements
            .subtitle1ThemeScalable(context)
            .copyWith(color: HexColor(AppColors.appMainColor)),

        contentPadding: const EdgeInsets.all(16),
        border: UnderlineInputBorder(borderRadius: BorderRadius.circular(12)),

        labelText: widget.firstItemTag,
      ),
    );

    return _getBody();
  }

  Widget _getBody() {
    return BlocBuilder<CubitMain, MainState>(builder: (context, state) {
      return Padding(
        padding: const EdgeInsets.all(4.0),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Padding(
              padding: const EdgeInsets.only(
                  bottom: 30.0, left: 16, right: 16, top: 8),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                //Center Row contents horizontally,
                crossAxisAlignment: CrossAxisAlignment.start,
                //Center Row contents vertically,

                children: [
                  Expanded(
                    child: Align(
                      alignment: Alignment.center,
                      child: Container(
                        child: Text(
                          widget.title,
                          textAlign: TextAlign.center,
                          style: styleElements
                              .subtitle1ThemeScalable(context)
                              .copyWith(fontWeight: FontWeight.bold),
                        ),
                      ),
                    ),
                  ),
                  Align(
                    alignment: Alignment.centerRight,
                    child: InkWell(
                      onTap: () {
                        if (state is LoadedWithData && state.data!=null) {
                          state.data!.cashOrCoins =
                              num.parse(cashController.text);
                        }

                        widget.nextCallBack(
                            state is LoadedWithData  && state.data!=null? state.data : null);
                      },
                      child: Container(
                        child: Text(
                          AppLocalizationsRewards.of(context)!
                              .translate("next"),
                          textAlign: TextAlign.center,
                          style: styleElements
                              .subtitle1ThemeScalable(context)
                              .copyWith(
                                  fontWeight: FontWeight.bold,
                                  color: HexColor(AppColors.blueApp)),
                        ),
                      ),
                    ),
                  )
                ],
              ),
            ),
            Padding(
              padding: const EdgeInsets.all(12),
              child: Text(
                widget.subTitle,
                textAlign: TextAlign.center,
                style: styleElements.captionThemeScalable(context),
              ),
            ),
            Padding(
              padding: const EdgeInsets.all(16),
              child: Wrap(
                children: [
                  Text(
                    AppLocalizationsRewards.of(context)!.translate(
                        widget.type == PaymentEnums.cash.type
                            ? 'billing_amount'
                            : 'cash_service_charge',
                        arguments: {
                          "serviceCHarge": state is LoadedWithData && state.data!=null
                              ? state.data.taxDetails.serviceCharge.toString()
                              : ""
                        }),
                    textAlign: TextAlign.center,
                    style: styleElements
                        .subtitle1ThemeScalable(context)
                        .copyWith(fontWeight: FontWeight.bold),
                  ),
                  state is LoadedWithData && state.data!=null
                      ? Padding(
                          padding: const EdgeInsets.only(left: 8.0),
                          child: Text(
                            state.data.payableAmount.toString(),
                            textAlign: TextAlign.center,
                            style: styleElements
                                .subtitle1ThemeScalable(context)
                                .copyWith(
                                    fontWeight: FontWeight.bold,
                                  ),
                          ),
                        )
                      : state is LoadingStatePagination
                          ? const SizedBox(
                              height: 20,
                              width: 20,
                              child: CircularProgressIndicator())
                          : Text(
                              "--",
                              textAlign: TextAlign.center,
                              style: styleElements
                                  .subtitle1ThemeScalable(context)
                                  .copyWith(
                                      fontWeight: FontWeight.bold,
                                      color: HexColor(AppColors.blueApp)),
                            )
                ],
              ),
            ),
            Flexible(
                child:
                    Padding(padding: const EdgeInsets.all(8.0), child: cash)),
            const SizedBox(
              width: 20,
            ),
            Padding(
              padding: const EdgeInsets.only(left:8.0,right:8.0),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  appElevatedButton(
                      elevation: 0,
                      shape: StadiumBorder(
                          side: BorderSide(
                              color: HexColor(AppColors.appColorWhite))),
                      onPressed: () {
                        setValue("100");
                      },
                      child: Text(
                        "100",
                        style: styleElements
                            .captionThemeScalable(context)
                            .copyWith(
                                color: state is LoadedWithData &&
                                        state.selectedNum == 100
                                    ? HexColor(AppColors.appColorWhite)
                                    : HexColor(AppColors.appColorBlack65)),
                      ),
                      color: state is LoadedWithData && state.selectedNum == 100
                          ? HexColor(AppColors.appMainColor)
                          : HexColor(AppColors.greyBg)),
                  appElevatedButton(
                      elevation: 0,
                      shape: StadiumBorder(
                          side: BorderSide(
                              color: HexColor(AppColors.appColorWhite))),
                      onPressed: () {
                        setValue("500");
                      },
                      child: Text(
                        "500",
                        style: styleElements
                            .captionThemeScalable(context)
                            .copyWith(
                            color: state is LoadedWithData &&
                                state.selectedNum == 500
                                ? HexColor(AppColors.appColorWhite)
                                : HexColor(AppColors.appColorBlack65)),
                      ),
                      color: state is LoadedWithData && state.selectedNum == 500
                          ? HexColor(AppColors.appMainColor)
                          : HexColor(AppColors.greyBg)),
                  appElevatedButton(
                      elevation: 0,
                      shape: StadiumBorder(
                          side: BorderSide(
                              color: HexColor(AppColors.appColorWhite))),
                      onPressed: () {
                        setValue("1000");
                      },
                      child: Text(
                        "1000",
                        style: styleElements
                            .captionThemeScalable(context)
                            .copyWith(
                            color: state is LoadedWithData &&
                                state.selectedNum == 1000
                                ? HexColor(AppColors.appColorWhite)
                                : HexColor(AppColors.appColorBlack65)),
                      ),
                      color: state is LoadedWithData && state.selectedNum == 1000
                          ? HexColor(AppColors.appMainColor)
                          : HexColor(AppColors.greyBg)),
                ],
              ),
            ),
            Padding(
              padding: const EdgeInsets.only(left:8.0,right:8.0),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  appElevatedButton(
                      elevation: 0,
                      shape: StadiumBorder(
                          side: BorderSide(
                              color: HexColor(AppColors.appColorWhite))),
                      onPressed: () {
                        setValue("1500");
                      },
                      child: Text(
                        "1500",
                        style: styleElements
                            .captionThemeScalable(context)
                            .copyWith(
                            color: state is LoadedWithData &&
                                state.selectedNum == 1500
                                ? HexColor(AppColors.appColorWhite)
                                : HexColor(AppColors.appColorBlack65)),
                      ),
                      color: state is LoadedWithData && state.selectedNum == 1500
                          ? HexColor(AppColors.appMainColor)
                          : HexColor(AppColors.greyBg)),
                  appElevatedButton(
                      elevation: 0,
                      shape: StadiumBorder(
                          side: BorderSide(
                              color: HexColor(AppColors.appColorWhite))),
                      onPressed: () {
                        setValue("2000");
                      },
                      child: Text(
                        "2000",
                        style: styleElements
                            .captionThemeScalable(context)
                            .copyWith(
                            color: state is LoadedWithData &&
                                state.selectedNum == 2000
                                ? HexColor(AppColors.appColorWhite)
                                : HexColor(AppColors.appColorBlack65)),
                      ),
                      color: state is LoadedWithData && state.selectedNum == 2000
                          ? HexColor(AppColors.appMainColor)
                          : HexColor(AppColors.greyBg)),
                  appElevatedButton(
                      elevation: 0,
                      shape: StadiumBorder(
                          side: BorderSide(
                              color: HexColor(AppColors.appColorWhite))),
                      onPressed: () {
                        setValue("3000");
                      },
                      child: Text(
                        "3000",
                        style: styleElements
                            .captionThemeScalable(context)
                            .copyWith(
                            color: state is LoadedWithData &&
                                state.selectedNum == 3000
                                ? HexColor(AppColors.appColorWhite)
                                : HexColor(AppColors.appColorBlack65)),
                      ),
                      color: state is LoadedWithData && state.selectedNum == 3000
                          ? HexColor(AppColors.appMainColor)
                          : HexColor(AppColors.greyBg)),
                ],
              ),
            ),
            SizedBox(
              height: MediaQuery.of(context).viewInsets.bottom,
            )
          ],
        ),
      );
    });
  }

  void setValue(String selectedValue) {
    BlocProvider.of<CubitMain>(context)
        .setPreselectedValue(num.parse(selectedValue));
    cashController.text = selectedValue;
    BlocProvider.of<CubitMain>(context).getCashCoinRechargeInfo(
        getBody(num.parse(selectedValue)),
        context,
        basicInfo!.fetchCashCoinData,
        getData,num.parse(selectedValue));
  }

  dynamic getData(dynamic data) {
    return CashCoinInfo.fromJson(data);
  }

  String getBody(num amount) {
    return jsonEncode({
      "business_id": basicInfo!.businessId,
      "amount": amount,
      "service_charge_type": widget.type,
      "country": "IN"
    });
  }
}
