import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:loyalty_management_tool/utils/locator.dart';

import 'package:shared_preferences/shared_preferences.dart';

import '../../../models/cash_coin_resppnse.dart';
import '../../../utils/basicInfo.dart';
import '../../../utils/colors.dart';
import '../../../utils/common_button.dart';
import '../../../utils/custom_app_bar.dart';
import '../../../utils/customcard.dart';
import '../../../utils/hexColors.dart';
import '../../../utils/localization.dart';
import '../../../utils/text_styling.dart';
import '../../common_widgets/account_details_billing_widget.dart';
import '../../common_widgets/header_widget.dart';
import '../../common_widgets/invoice_card.dart';
import '../../cubits/cubit_main.dart';
import '../../states/main_state.dart';

class PaymentPage extends StatelessWidget {
  final String title;
  final String type;
  final SharedPreferences? prefs = locatorRewards<SharedPreferences>();
  BasicInfo? basicInfo = BasicInfo();

  final Rows data;

  PaymentPage({required this.title, required this.type, required this.data});

  late TextStyleElements styleElements;

  GlobalKey<AccountDetailsBillingWidgetState> keyAddress = GlobalKey();

  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);

    // BlocProvider.of<CubitMain>(context).getPrivacyPolicyData("", context);
    return BlocBuilder<CubitMain, MainState>(
      builder: (context, state) {
        return Scaffold(
          appBar: appAppBar().getCustomAppBar(
            context,
            appBarTitle: title,
            onBackButtonPress: () {
              Navigator.pop(context);
            },
          ),
          body: Stack(
            children: [
              ListView(
                children: [
                  appCard(
                    child: Column(
                      mainAxisSize: MainAxisSize.min,
                      children: [
                        HeaderWidget(
                            avatar: basicInfo!.userImage,
                            title: basicInfo!.userName,
                            subTitle: "Business Location ",
                            baseUrl: '',
                            refreshCallBack: () {
                              keyAddress.currentState!.dataFetch();
                            }),
                        BlocProvider(
                          create: (_) => CubitMain(),
                          child: AccountDetailsBillingWidget(
                            key: keyAddress,
                            title: basicInfo!.userName,
                          ),
                        ),
                      ],
                    ),
                  ),
                  appCard(
                      child: InvoiceCard(
                    data: data,
                    title: "Title",
                    subTitle: type,
                  )),
                ],
              ),
              Align(
                  alignment: Alignment.bottomCenter,
                  child: Container(
                      color: HexColor(AppColors.appMainColor),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: <Widget>[
                          Padding(
                            padding: const EdgeInsets.only(left: 8.0),
                            child: AppButtonCommon(
                              shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(18.0),
                                  side: BorderSide(
                                      color: HexColor(AppColors.appMainColor))),
                              onPressed: () async {},
                              color: HexColor(AppColors.appColorWhite),
                              child: Column(
                                mainAxisSize: MainAxisSize.min,
                                children: [
                                  Text(
                                    AppLocalizationsRewards.of(context)!
                                        .translate('total_pay'),
                                    style: styleElements
                                        .captionThemeScalable(context)
                                        .copyWith(
                                            fontWeight: FontWeight.w600,
                                            color: HexColor(
                                                AppColors.appColorWhite)),
                                  ),
                                  Text(
                                    "₹" + data.payableAmount.toString(),
                                    style: styleElements
                                        .headline6ThemeScalableW(context)
                                        .copyWith(
                                            fontWeight: FontWeight.w600,
                                            color: HexColor(
                                                AppColors.appColorWhite)),
                                  ),
                                ],
                              ),
                            ),
                          ),
                          Padding(
                            padding: const EdgeInsets.only(right: 8.0),
                            child: AppButtonCommon(
                              shape: RoundedRectangleBorder(
                                  borderRadius: BorderRadius.circular(18.0),
                                  side: BorderSide(
                                      color: HexColor(AppColors.appMainColor))),
                              onPressed: () async {},
                              color: HexColor(AppColors.appColorWhite),
                              child: Row(
                                mainAxisSize: MainAxisSize.min,
                                mainAxisAlignment: MainAxisAlignment.center,
                                children: [
                                  Text(
                                    AppLocalizationsRewards.of(context)!
                                        .translate('pay'),
                                    style: styleElements
                                        .headline6ThemeScalableW(context)
                                        .copyWith(
                                            color: HexColor(
                                                AppColors.appColorWhite)),
                                  ),
                                  Padding(
                                    padding: const EdgeInsets.all(2.0),
                                    child: Icon(
                                      Icons.arrow_forward_ios,
                                      color: HexColor(AppColors.appColorWhite),
                                    ),
                                  )
                                ],
                              ),
                            ),
                          ),
                        ],
                      )))
            ],
          ),
        );
      },
    );
  }

  String numberOfUsers() {
    return "3";
  }
}
